@@ -15,15 +15,6 @@ import subprocess
 def install(package):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
-try:
-
-    import pixplot
-
-except BaseException as e:
-    install('pixplot')
-    import pixplot
-
-    print("Success! :)")
 try:
 
     from keras.backend.tensorflow_backend import set_session
@@ -1064,6 +1055,7 @@ def write_images(**kwargs):
         if not exists(out_dir): os.makedirs(out_dir)
         out_path = join(out_dir, filename)
         img = array_to_img(i.resize_to_max(kwargs['lod_cell_height']))
+        print("Output Saving to:",out_path)
         save_img(out_path, img)
 
 
